@@ -6,6 +6,7 @@ from df_and_order.df_transform import DfTransformConfig
 from df_and_order.df_config import DfConfig
 from df_and_order.df_cache import DfCache
 from df_and_order.df_transform_step import DfTransformStepConfig, DfTransformStep
+from df_and_order.helpers import FileInspector, get_type_from_module_path
 
 
 class DfReader:
@@ -56,7 +57,21 @@ class DfReader:
         df_path = self._df_path(df_config=df_config,
                                 df_id=df_id,
                                 transform_id=transform_id)
-        return os.path.exists(path=df_path)
+        return DfReader._is_file_exists(path=df_path)
+
+    def _df_last_modified_ts(self,
+                             df_id: str,
+                             transform_id: Optional[str] = None) -> float:
+        df_config = self._get_config(df_id=df_id)
+        df_path = self._df_path(df_config=df_config,
+                                df_id=df_id,
+                                transform_id=transform_id)
+        result = FileInspector.last_modified_date(file_path=df_path)
+        return result
+
+    @staticmethod
+    def _is_file_exists(path: str):
+        return os.path.exists(path=path)
 
     def create_df_config(self,
                          df_id: str,
@@ -150,6 +165,26 @@ class DfReader:
                                                transform_id=transform_id)
         df_format = df_config.transformed_df_format
         if transformed_df_exists:
+            if transform.permanent_steps:
+                # if the code of one of the steps was modified since the transformed dataframe
+                # was cached - we need to stop and warn a user about the need of regenerating it
+                df_last_modified_date = self._df_last_modified_ts(df_id=df_id,
+                                                                  transform_id=transform_id)
+
+                def _filter_func(step_config: DfTransformStepConfig):
+                    # built-in types override the method to provide true last modification date
+                    step_class = get_type_from_module_path(module_path=step_config.module_path)
+                    step_last_modified_ts = step_class.step_last_modified_ts(step_config=step_config)
+                    result = step_last_modified_ts > df_last_modified_date
+                    return result
+
+                outdated_steps = list(filter(_filter_func, transform.permanent_steps))
+
+                if len(outdated_steps) > 0:
+                    steps_module_paths = [step.module_path for step in outdated_steps]
+                    raise Exception(f'{steps_module_paths} steps were changed since the df was generated, '
+                                    'delete the file and try again to regenerate the df.')
+
             df = self._read_df(df_config=df_config,
                                df_id=df_id,
                                df_format=df_format,
